#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-GcPDH4AQCQw4yy9nA09CWM
key:                  persistent-mysql-2.13.1.5-GcPDH4AQCQw4yy9nA09CWM
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  3ecc319f15d52b56519caa248334cbc1
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-GcPDH4AQCQw4yy9nA09CWM
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1
    blaze-builder-0.4.4.1-CVV6q4pVvXFBczRCmYuxry bytestring-0.11.5.3
    conduit-1.3.6.1-A5CFvWaedHyBbFpBELr7ED containers-0.6.7
    monad-logger-0.3.42-9nXe4zEtCrVBsRKA8Lng7G
    mysql-0.2.1-LCbaBXviJWa5Dg22Fa3Pa2
    mysql-simple-0.4.9-7C4jeLCmuKfCbecrlzBZVx
    persistent-2.14.6.1-GEU3f5Qg3bVH7PMKZ9qrSb
    resource-pool-0.3.0.0-JXzbLnfBLeD7Fj2nCfJbLZ
    resourcet-1.3.0-G1Jndw6mtoEGFSzuHCFgbA text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

